@@ -284,9 +284,10 @@ EJS
     options = ({
       :alt => payment.name
     }).merge(options)
-    id = payment.resource_id
-    if id
-      view_resource_id(id, options)
+    if payment.use_remote_resource
+      image_tag(payment.resource_url, options) unless payment.resource_url.blank?
+    elsif payment.resource_id
+      view_resource_id(payment.resource_id, options)
     else
       ''
     end
@@ -321,6 +322,20 @@ EJS
     end
   end
 
+  def logo_without_text(payment)
+    if payment.use_remote_resource
+      if !payment.resource_url.blank? && payment.without_text
+        true
+      else
+        false
+      end
+    elsif payment.resource_id && payment.without_text
+      true
+    else
+      false
+    end 
+  end
+
 =begin rdoc
   <select>
    <option value="x">食料</option>
@@ -361,7 +376,7 @@ def product_category_image_tag(product)
 end
 
 def category_image_tag(category)
-  default = image_tag('title_cat00.jpg', :alt=>"カテゴリー")
+  default = image_tag('title_cat00.gif', :alt=>"カテゴリー")
   category or return default
   category.resource_id.blank? and return default
   view_resource_id(category.menu_resource_id, :alt=>category.name)
@@ -387,9 +402,10 @@ def each_product_styles(product)
 end
 
 def image_tag_mobile(prefix, options={})
-  width = request.mobile.display.width
+  width = request.mobile.display.width if request.mobile and request.mobile.display
+  width = options[:width] if options[:width]
   size = 'q' # q = QVGA, v = VGA
-  size = 'v' if !width.blank? && width >= 480
+  size = 'v' if !width.blank? && width.to_i >= 480
   format = 'gif'
   #キャリア毎に変更するなら以下を利用する（今は使わないのでコメントアウト
   #format = 'gif' if request.mobile.is_a?(Jpmobile::Mobile::Docomo)
