@@ -24,6 +24,7 @@ class Product < ActiveRecord::Base
   has_many :order_details
   has_one :campaign
   belongs_to :supplier
+  belongs_to :retailer
 
   validates_length_of :name , :maximum => 50
   validates_length_of :name , :minimum => 1
@@ -35,6 +36,7 @@ class Product < ActiveRecord::Base
   validates_presence_of :description
   validates_presence_of :introduction
   validates_presence_of :supplier
+  validates_presence_of :retailer
   validates_associated :sub_products
 
   attr_accessor :small_resource_path
@@ -127,6 +129,9 @@ class Product < ActiveRecord::Base
   def supplier_name
     self.supplier && self.supplier.name
   end
+  def retailer_name
+    self.retailer && self.retailer.name
+  end
   # 送料無料？
   def free_delivery?
     statuses.exists?(['name=?', '送料無料'])
@@ -263,6 +268,9 @@ class Product < ActiveRecord::Base
       unless search.sale_start_at_end.blank?
         search_list << ["products.sale_start_at <= ?", search.sale_start_at_end + 1.day]
       end
+      unless search.retailer_id.blank?
+        search_list << ["products.retailer_id = ?", search.retailer_id]
+      end
     end
     unless params["product_status_ids"].blank?
       product_status = ProductStatus.find(:all, :select => "distinct product_id",  :conditions => "status_id IN (#{ params["product_status_ids"].join(",") })" )
@@ -292,7 +300,7 @@ class Product < ActiveRecord::Base
             end
           elsif column.to_s == "delivery_dates_label"
             product.delivery_dates_label
-          elsif ![:small_resource_path,:medium_resource_path,:large_resource_path,:category_name,:delivery_dates_label,:supplier_name].include?(column)&& Product.columns_hash[column.to_s].type == :datetime
+          elsif ![:small_resource_path,:medium_resource_path,:large_resource_path,:category_name,:delivery_dates_label,:supplier_name,:retailer_name].include?(column)&& Product.columns_hash[column.to_s].class == :datetime
             (product[column] + (60*60*9)).strftime("%Y-%m-%d %H:%M") if product[column]
           else
             product[column] || product.send(column)
@@ -326,13 +334,20 @@ class Product < ActiveRecord::Base
     [f.string, filename]
   end
 
+  def master_shop?
+    return retailer_id == Retailer::DEFAULT_ID
+  end
+
   class << self
-    def add_by_csv(file)
+    def add_by_csv(file, retailer_id)
       line = 0
       Product.transaction do
         CSV::Reader.parse(file) do |row|
           if line != 0
-            product = new_by_array(row)
+            product = new_by_array(row, retailer_id)
+            if product.nil?
+              return [line-1, false]              
+            end
             unless product.save!
               return [line-1, false]
             end
@@ -345,21 +360,26 @@ class Product < ActiveRecord::Base
 
     private
 
-    def new_by_array(arr)
+    def new_by_array(arr, retailer_id)
       arr.map! do | val |
         Iconv.conv('UTF-8', 'cp932', val)
       end
+      # retailer_idの確認
+      product = Product.find_by_id(arr[0].to_i) unless arr[0].blank?
+      if retailer_id != Retailer::DEFAULT_ID && product && product.retailer_id != retailer_id
+        return nil
+      end
       #arr[0]が対応しているデータ存在する時、更新、存在しない時、新規作成
-      unless !arr[0].blank? && product = Product.find_by_id(arr[0].to_i)
+      unless product
         product = Product.new
       end
       #CSVデータ設定
-      set_data(product,arr)
+      set_data(product,arr,retailer_id)
       product
     end
 
     #CSVデータ設定
-    def set_data(product,arr)
+    def set_data(product,arr,retailer_id)
       setPermit(product, arr[1])
       product.name = arr[2]
       product.url = arr[3]
@@ -386,6 +406,12 @@ class Product < ActiveRecord::Base
       product.free_comment = arr[29]
       setDelivery_dates(product,arr[30])
       setSupplierId(product,arr[31])
+      # todo: csvupload retailer対応
+      if retailer_id == Retailer::DEFAULT_ID
+        setRetailerId(product,arr[32])
+      else
+        setRetailerId(product,arr[32],retailer_id)
+      end
     end
 
     def setPermit(product, permit)
@@ -411,6 +437,21 @@ class Product < ActiveRecord::Base
         end        
       end
     end
+
+    def setRetailerId(product, name, retailer_id = nil)
+      if name.blank? && retailer_id.nil?
+        product.retailer_id = Retailer::DEFAULT_ID
+      elsif retailer_id
+        product.retailer_id = retailer_id
+      else
+        r = Retailer.find_by_name(name)
+        if !r.blank?
+          product.retailer_id = r.id
+        else
+          raise ActiveRecord::RecordNotFound
+        end
+      end
+    end
     #画像データセット
     def setImageId(product,arr)
       #画像IDと画像パスの項目を別々に設定して画像パスがあった場合は、その先にある画像を登録し、なかった場合は画像IDを登録する
@@ -530,6 +571,7 @@ class Product < ActiveRecord::Base
       :free_comment,
       :delivery_dates_label,
       :supplier_name,
+      :retailer_name,
       :created_at,
       :updated_at
     ]
@@ -569,6 +611,7 @@ class Product < ActiveRecord::Base
       :free_comment => "フリー入力",
       :delivery_dates_label => "配送日",
       :supplier_name => "仕入先名",
+      :retailer_name => "販売元名",
       :created_at => "登録日",
       :updated_at => "更新日"
     }
