@@ -1,7 +1,8 @@
+# -*- coding: utf-8 -*-
 require File.dirname(__FILE__) + '/../spec_helper'
 
 describe CampaignsController do
-  fixtures :campaigns, :products, :customers
+  fixtures :campaigns, :products, :customers, :systems
 
   before do
     session[:customer_id] = customers(:valid_signup).id
